#
#   ____ _ ____         ___                   ____                   ___       _             __                
#  / ___(_)  _ \   _   / _ \ _ __   ___ _ __ / ___|  ___  ___  ___  |_ _|_ __ | |_ ___ _ __ / _| __ _  ___ ___ 
# | |  _| | | | |_| |_| | | | '_ \ / _ \ '_ \\___ \ / _ \/ _ \/ __|  | || '_ \| __/ _ \ '__| |_ / _` |/ __/ _ \
# | |_| | | |_| |_   _| |_| | |_) |  __/ | | |___) |  __/  __/\__ \  | || | | | ||  __/ |  |  _| (_| | (_|  __/
#  \____|_|____/  |_|  \___/| .__/ \___|_| |_|____/ \___|\___||___/ |___|_| |_|\__\___|_|  |_|  \__,_|\___\___|
#                           |_|                                                                                
#
# GiD + OpenSees Interface - An Integrated FEA Platform
# Copyright (C) 2016-2018
#
# Lab of R/C and Masonry Structures
# School of Civil Engineering, AUTh
#
# Development team
#
# T. Kartalis-Kaounis, Civil Engineer AUTh
# V. Protopapadakis, Civil Engineer AUTh
# T. Papadopoulos, Civil Engineer AUTh
#
# Project coordinator
#
# V.K. Papanikolaou, Assistant Professor AUTh
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

# --------------------------------------------------------------------------------------------------------------
# U N I T S
# --------------------------------------------------------------------------------------------------------------

# Length : m
# Force  : kN
# Moment : kNm
# Stress : kPa
# Mass   : ton

# --------------------------------------------------------------------------------------------------------------
# E L E M E N T S  U S E D
# --------------------------------------------------------------------------------------------------------------

# C1 (2)
# C2 (2)
# C4 (1)
# C5 (2)
# C7 (2)
# C9 (2)
# C10 (2)
# C12 (1)
# C13 (2)
# C15 (2)
# C17 (2)
# C18 (2)
# C20 (1)
# C21 (2)
# C23 (1)
# C24 (2)
# C26 (2)
# C27 (4)
# C29 (2)
# C30 (2)
# C32 (1)
# C33 (2)
# C35 (1)
# C36 (2)
# C38 (2)
# B1 (8)
# B2 (4)
# B3 (2)
# B4 (8)
# B5 (4)
# B6 (4)
# B7 (36)
# B8 (4)
# B9 (26)
# B10 (16)
# B11 (22)
# B13 (24)
# B14 (15)
# W1 (1)
# W2 (1)
# W3 (1)
# Inf - 1 (2)
# Inf - 2 (6)
# Inf - 3 (2)
# Inf - 4 (2)
# Inf - 6 (2)
# Inf - 7 (1)
# Inf - 8 (12)
# Inf - 9 (3)
# Inf - 10 (2)
# Inf - 11 (2)
# Inf - 12 (1)
# Inf - 13 (1)
# Inf - 14 (3)
# Inf - 15 (3)
# Inf - 16 (3)
# Inf - 17 (1)
# Inf - 18 (2)
# Inf - 19 (2)
# Inf - 20 (1)
# Inf - 21 (1)
# Inf - 22 (3)
# Inf - 23 (3)
# Inf - 24 (1)
# Inf - 25 (1)
# Inf - 26 (2)
# Inf - 27 (2)
# Inf - 28 (2)
# Inf - 29 (1)
# Inf - 30 (1)
# Inf - 31 (3)
# Inf - 32 (3)
# Inf - 33 (1)
# Inf - 34 (2)
# Inf - 35 (1)
# Inf - 36 (1)
# Inf - 37 (1)
# Inf - 38 (2)

# --------------------------------------------------------------------------------------------------------------
#
# M O D E L  D O M A I N  1  (3DOF)
#
# --------------------------------------------------------------------------------------------------------------

model BasicBuilder -ndm 3 -ndf 3

# --------------------------------------------------------------------------------------------------------------
# N O D E S
# --------------------------------------------------------------------------------------------------------------

# node $NodeTag $XCoord $Ycoord $Zcoord

node      2            0        12.33          3.4
node      3            0           14          3.4
node      6            0            7          3.4
node      7            0        12.33          6.4
node      8            0           14          6.4
node     12         7.35        12.33          3.4
node     14            0            7          6.4
node     15          6.2            7          3.4
node     18            0        12.33          9.4
node     19            0           14          9.4
node     20         7.35            7          3.4
node     21         7.35        12.33          6.4
node     24          6.2            7          6.4
node     25          8.5            7          3.4
node     27            0            7          9.4
node     28         7.35            7          6.4
node     29            0         1.68          3.4
node     33          8.5            7          6.4
node     34         7.35        12.33          9.4
node     37            0        12.33         12.4
node     39            0         1.68          6.4
node     41          6.2            7          9.4
node     42            0           14         12.4
node     43          6.2         1.68          3.4
node     44            0            0          3.4
node     47         7.35            7          9.4
node     51            0            7         12.4
node     55          8.5            7          9.4
node     56          6.2         1.68          6.4
node     57            0            0          6.4
node     59          8.5         1.68          3.4
node     61            0         1.68          9.4
node     63         7.35        12.33         12.4
node     71          8.5         1.68          6.4
node     72         14.7        12.33          3.4
node     73         14.7           14          3.4
node     75         7.35            7         12.4
node     76            0        12.33         15.4
node     79          6.2         1.68          9.4
node     80            0            0          9.4
node     85         14.7            7          3.4
node     87         14.7        12.33          6.4
node     88         14.7           14          6.4
node     89            0            7         15.4
node     90            0         1.68         12.4
node     93          8.5         1.68          9.4
node     97         14.7            7          6.4
node     99         7.35        12.33         15.4
node    102         14.7        12.33          9.4
node    104            0            0         12.4
node    106         14.7           14          9.4
node    109         7.35            7         15.4
node    110         7.35         1.68         12.4
node    112         14.7            7          9.4
node    114         14.7         1.68          3.4
node    115            0         1.68         15.4
node    120         14.7        12.33         12.4
node    121         14.7         1.68          6.4
node    122         14.7           14         12.4
node    124         14.7            0          3.4
node    128         14.7            7         12.4
node    129         7.35         1.68         15.4
node    130         14.7            0          6.4
node    132         14.7         1.68          9.4
node    133         14.7        12.33         15.4
node    135         14.7            0          9.4
node    137         14.7            7         15.4
node    138         14.7         1.68         12.4
node    139         14.7            0         12.4
node    140         14.7         1.68         15.4

# --------------------------------------------------------------------------------------------------------------
# M A S S E S
# --------------------------------------------------------------------------------------------------------------

# Mass Definition : mass $NodeTag $(ndf nodal mass values corresponding to each DOF)

mass     20    159.1    159.1        0
mass     28    158.6    158.6        0
mass     47    145.6    145.6        0
mass     75    154.6    154.6        0
mass    109    102.4    102.4        0

# --------------------------------------------------------------------------------------------------------------
# T R U S S   E L E M E N T S
# --------------------------------------------------------------------------------------------------------------

# Uniaxial Materials definition used by Truss Elements
# (ïnly if they have not been already defined on this model domain)

uniaxialMaterial Hysteretic 1187 0.396 1.85e-07 0.546 7.42e-07 0.011 3.71e-06 -395.697 -0.000185 -546.062 -0.00074 -10.921 -0.00371 1 1 0 0 0
uniaxialMaterial Hysteretic 1188 0.475 1.85e-07 0.655 8.28e-07 0.013 4.14e-06 -474.836 -0.000185 -655.274 -0.00083 -13.105 -0.00414 1 1 0 0 0
uniaxialMaterial Hysteretic 1189 0.169 1.32e-07 0.233 2.13e-07 0.005 1.06e-06 -168.685 -0.000132 -232.785 -0.00021 -4.656 -0.00106 1 1 0 0 0
uniaxialMaterial Hysteretic 1190 0.169 1.32e-07 0.233 1.8e-07 0.005 8.98e-07 -168.685 -0.000132 -232.785 -0.00018 -4.656 -0.0009 1 1 0 0 0
uniaxialMaterial Hysteretic 1192 0.254 1.77e-07 0.35 4.08e-07 0.007 2.04e-06 -253.889 -0.000177 -350.367 -0.00041 -7.007 -0.00204 1 1 0 0 0
uniaxialMaterial Hysteretic 1193 0.254 1.77e-07 0.35 3.44e-07 0.007 1.72e-06 -253.889 -0.000177 -350.367 -0.00034 -7.007 -0.00172 1 1 0 0 0
uniaxialMaterial Hysteretic 1194 0.254 3.29e-07 0.351 8.01e-07 0.007 4.01e-06 -254.156 -0.000329 -350.736 -0.0008 -7.015 -0.00401 1 1 0 0 0
uniaxialMaterial Hysteretic 1195 0.254 3.38e-07 0.351 8.02e-07 0.007 4.01e-06 -254.156 -0.000338 -350.736 -0.0008 -7.015 -0.00401 1 1 0 0 0
uniaxialMaterial Hysteretic 1196 0.204 1.77e-07 0.282 3.43e-07 0.006 1.72e-06 -204.075 -0.000177 -281.624 -0.00034 -5.632 -0.00172 1 1 0 0 0
uniaxialMaterial Hysteretic 1197 0.204 1.77e-07 0.282 2.31e-07 0.006 1.15e-06 -204.075 -0.000177 -281.624 -0.00023 -5.632 -0.00115 1 1 0 0 0
uniaxialMaterial Hysteretic 1198 0.4 1.85e-07 0.552 7.51e-07 0.011 3.76e-06 -399.714 -0.000185 -551.606 -0.00075 -11.032 -0.00376 1 1 0 0 0
uniaxialMaterial Hysteretic 1199 0.4 1.85e-07 0.552 9.25e-07 0.011 4.63e-06 -399.714 -0.000185 -551.606 -0.00093 -11.032 -0.00463 1 1 0 0 0
uniaxialMaterial Hysteretic 1200 0.48 1.85e-07 0.662 1.03e-06 0.013 5.16e-06 -479.657 -0.000185 -661.927 -0.00103 -13.239 -0.00516 1 1 0 0 0
uniaxialMaterial Hysteretic 1201 0.48 1.85e-07 0.662 8.38e-07 0.013 4.19e-06 -479.657 -0.000185 -661.927 -0.00084 -13.239 -0.00419 1 1 0 0 0
uniaxialMaterial Hysteretic 1202 0.093 1.32e-07 0.128 1.42e-07 0.003 7.1e-07 -93.041 -0.000132 -128.397 -0.00014 -2.568 -0.00071 1 1 0 0 0
uniaxialMaterial Hysteretic 1203 0.176 1.32e-07 0.243 1.88e-07 0.005 9.4e-07 -176.249 -0.000132 -243.223 -0.00019 -4.864 -0.00094 1 1 0 0 0
uniaxialMaterial Hysteretic 1204 0.215 1.77e-07 0.297 3.65e-07 0.006 1.82e-06 -215.323 -0.000177 -297.146 -0.00036 -5.943 -0.00182 1 1 0 0 0
uniaxialMaterial Hysteretic 1205 0.215 1.77e-07 0.297 5.21e-07 0.006 2.61e-06 -215.323 -0.000177 -297.146 -0.00052 -5.943 -0.00261 1 1 0 0 0
uniaxialMaterial Hysteretic 1206 0.482 1.85e-07 0.665 1.44e-06 0.013 7.18e-06 -482.067 -0.000185 -665.253 -0.00144 -13.305 -0.00718 1 1 0 0 0
uniaxialMaterial Hysteretic 1207 0.482 1.85e-07 0.665 8.43e-07 0.013 4.21e-06 -482.067 -0.000185 -665.253 -0.00084 -13.305 -0.00421 1 1 0 0 0
uniaxialMaterial Hysteretic 1208 0.402 1.85e-07 0.554 7.56e-07 0.011 3.78e-06 -401.723 -0.000185 -554.377 -0.00076 -11.088 -0.00378 1 1 0 0 0
uniaxialMaterial Hysteretic 1209 0.402 1.85e-07 0.554 1.29e-06 0.011 6.44e-06 -401.723 -0.000185 -554.377 -0.00129 -11.088 -0.00644 1 1 0 0 0
uniaxialMaterial Hysteretic 1210 0.402 1.9e-07 0.554 9.27e-07 0.011 4.63e-06 -401.723 -0.00019 -554.377 -0.00093 -11.088 -0.00463 1 1 0 0 0
uniaxialMaterial Hysteretic 1211 0.402 1.9e-07 0.554 7.68e-07 0.011 3.84e-06 -401.723 -0.00019 -554.377 -0.00077 -11.088 -0.00384 1 1 0 0 0
uniaxialMaterial Hysteretic 1212 0.538 1.34e-07 0.743 1.5e-06 0.015 7.5e-06 -538.318 -0.000134 -742.878 -0.0015 -14.858 -0.0075 1 1 0 0 0
uniaxialMaterial Hysteretic 1213 0.542 1.31e-07 0.749 1.15e-06 0.015 5.75e-06 -542.452 -0.000131 -748.583 -0.00115 -14.972 -0.00575 1 1 0 0 0
uniaxialMaterial Hysteretic 1214 0.542 1.31e-07 0.749 1.48e-06 0.015 7.4e-06 -542.452 -0.000131 -748.583 -0.00148 -14.972 -0.0074 1 1 0 0 0
uniaxialMaterial Hysteretic 1215 0.327 1.77e-07 0.451 1.44e-06 0.009 7.21e-06 -326.842 -0.000177 -451.041 -0.00144 -9.021 -0.00721 1 1 0 0 0
uniaxialMaterial Hysteretic 1216 0.327 1.77e-07 0.451 7.94e-07 0.009 3.97e-06 -326.842 -0.000177 -451.041 -0.00079 -9.021 -0.00397 1 1 0 0 0
uniaxialMaterial Hysteretic 1217 0.403 1.9e-07 0.555 1.69e-06 0.011 8.44e-06 -402.526 -0.00019 -555.486 -0.00169 -11.11 -0.00844 1 1 0 0 0
uniaxialMaterial Hysteretic 1218 0.403 1.9e-07 0.555 7.7e-07 0.011 3.85e-06 -402.526 -0.00019 -555.486 -0.00077 -11.11 -0.00385 1 1 0 0 0
uniaxialMaterial Hysteretic 1219 0.22 3.38e-07 0.303 6.19e-07 0.006 3.1e-06 -219.694 -0.000338 -303.178 -0.00062 -6.064 -0.0031 1 1 0 0 0
uniaxialMaterial Hysteretic 1220 0.331 2.11e-07 0.457 1.71e-06 0.009 8.56e-06 -331.321 -0.000211 -457.224 -0.00171 -9.144 -0.00856 1 1 0 0 0
uniaxialMaterial Hysteretic 1221 0.327 1.9e-07 0.451 8.27e-07 0.009 4.14e-06 -326.842 -0.00019 -451.041 -0.00083 -9.021 -0.00414 1 1 0 0 0
uniaxialMaterial Hysteretic 1222 0.327 1.9e-07 0.451 1.5e-06 0.009 7.52e-06 -326.842 -0.00019 -451.041 -0.0015 -9.021 -0.00752 1 1 0 0 0
uniaxialMaterial Hysteretic 1223 0.233 2.59e-07 0.321 1.57e-06 0.006 7.84e-06 -232.686 -0.000259 -321.106 -0.00157 -6.422 -0.00784 1 1 0 0 0
uniaxialMaterial Hysteretic 1224 0.233 2.59e-07 0.321 8.63e-07 0.006 4.31e-06 -232.686 -0.000259 -321.106 -0.00086 -6.422 -0.00431 1 1 0 0 0

# Truss Definition : element truss $eleTag $inode $jnode $A $matTag -rho $rho -cMass $cFlag -doRayleigh $rFlag

element truss      1      6     7            1 1187   -rho        0 -cMass 0 -doRayleigh 0
element truss      2      2    14            1 1187   -rho        0 -cMass 0 -doRayleigh 0
element truss      3     29    14            1 1188   -rho        0 -cMass 0 -doRayleigh 0
element truss      4      6    39            1 1188   -rho        0 -cMass 0 -doRayleigh 0
element truss      5     85   121            1 1188   -rho        0 -cMass 0 -doRayleigh 0
element truss      6    114    97            1 1188   -rho        0 -cMass 0 -doRayleigh 0
element truss      7     72    97            1 1188   -rho        0 -cMass 0 -doRayleigh 0
element truss      8     85    87            1 1188   -rho        0 -cMass 0 -doRayleigh 0
element truss      9      6    28            1 1189   -rho        0 -cMass 0 -doRayleigh 0
element truss     10     20    14            1 1190   -rho        0 -cMass 0 -doRayleigh 0
element truss     11     20    97            1 1190   -rho        0 -cMass 0 -doRayleigh 0
element truss     12     85    28            1 1189   -rho        0 -cMass 0 -doRayleigh 0
element truss     13     20    21            1 1196   -rho        0 -cMass 0 -doRayleigh 0
element truss     14     12    28            1 1197   -rho        0 -cMass 0 -doRayleigh 0
element truss     15     43    24            1 1224   -rho        0 -cMass 0 -doRayleigh 0
element truss     16     15    56            1 1192   -rho        0 -cMass 0 -doRayleigh 0
element truss     17     59    33            1 1196   -rho        0 -cMass 0 -doRayleigh 0
element truss     18     25    71            1 1197   -rho        0 -cMass 0 -doRayleigh 0
element truss     19      7     3            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     20     39    44            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     21    121   124            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     22     87    73            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     23      7    27            1 1198   -rho        0 -cMass 0 -doRayleigh 0
element truss     24     14    18            1 1199   -rho        0 -cMass 0 -doRayleigh 0
element truss     25     14    61            1 1200   -rho        0 -cMass 0 -doRayleigh 0
element truss     26     39    27            1 1201   -rho        0 -cMass 0 -doRayleigh 0
element truss     27    121   112            1 1200   -rho        0 -cMass 0 -doRayleigh 0
element truss     28     97   132            1 1201   -rho        0 -cMass 0 -doRayleigh 0
element truss     29     97   102            1 1201   -rho        0 -cMass 0 -doRayleigh 0
element truss     30     87   112            1 1200   -rho        0 -cMass 0 -doRayleigh 0
element truss     31     14    47            1 1202   -rho        0 -cMass 0 -doRayleigh 0
element truss     32     28    27            1 1202   -rho        0 -cMass 0 -doRayleigh 0
element truss     33     28   112            1 1203   -rho        0 -cMass 0 -doRayleigh 0
element truss     34     97    47            1 1202   -rho        0 -cMass 0 -doRayleigh 0
element truss     35     28    34            1 1204   -rho        0 -cMass 0 -doRayleigh 0
element truss     36     21    47            1 1205   -rho        0 -cMass 0 -doRayleigh 0
element truss     37     56    41            1 1193   -rho        0 -cMass 0 -doRayleigh 0
element truss     38     24    79            1 1192   -rho        0 -cMass 0 -doRayleigh 0
element truss     39     71    55            1 1204   -rho        0 -cMass 0 -doRayleigh 0
element truss     40     33    93            1 1205   -rho        0 -cMass 0 -doRayleigh 0
element truss     41     18     8            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     42     61    57            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     43    132   130            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     44    102    88            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     45     37    19            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     46     18    51            1 1206   -rho        0 -cMass 0 -doRayleigh 0
element truss     47     27    37            1 1207   -rho        0 -cMass 0 -doRayleigh 0
element truss     48     27    90            1 1208   -rho        0 -cMass 0 -doRayleigh 0
element truss     49     61    51            1 1209   -rho        0 -cMass 0 -doRayleigh 0
element truss     50     90    80            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     51    138   135            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     52    112   138            1 1208   -rho        0 -cMass 0 -doRayleigh 0
element truss     53    132   128            1 1209   -rho        0 -cMass 0 -doRayleigh 0
element truss     54    102   128            1 1209   -rho        0 -cMass 0 -doRayleigh 0
element truss     55    112   120            1 1208   -rho        0 -cMass 0 -doRayleigh 0
element truss     56    120   106            1 1194   -rho        0 -cMass 0 -doRayleigh 0
element truss     57     27    75            1 1213   -rho        0 -cMass 0 -doRayleigh 0
element truss     58     47    51            1 1214   -rho        0 -cMass 0 -doRayleigh 0
element truss     59     47   128            1 1214   -rho        0 -cMass 0 -doRayleigh 0
element truss     60    112    75            1 1213   -rho        0 -cMass 0 -doRayleigh 0
element truss     61     47    63            1 1215   -rho        0 -cMass 0 -doRayleigh 0
element truss     62     34    75            1 1216   -rho        0 -cMass 0 -doRayleigh 0
element truss     63     76    42            1 1195   -rho        0 -cMass 0 -doRayleigh 0
element truss     64     37    89            1 1217   -rho        0 -cMass 0 -doRayleigh 0
element truss     65     51    76            1 1218   -rho        0 -cMass 0 -doRayleigh 0
element truss     66     51   115            1 1218   -rho        0 -cMass 0 -doRayleigh 0
element truss     67     90    89            1 1217   -rho        0 -cMass 0 -doRayleigh 0
element truss     68    115   104            1 1219   -rho        0 -cMass 0 -doRayleigh 0
element truss     69    140   139            1 1195   -rho        0 -cMass 0 -doRayleigh 0
element truss     70    138   137            1 1218   -rho        0 -cMass 0 -doRayleigh 0
element truss     71    128   140            1 1217   -rho        0 -cMass 0 -doRayleigh 0
element truss     72    128   133            1 1210   -rho        0 -cMass 0 -doRayleigh 0
element truss     73    120   137            1 1211   -rho        0 -cMass 0 -doRayleigh 0
element truss     74    133   122            1 1195   -rho        0 -cMass 0 -doRayleigh 0
element truss     75     51   109            1 1212   -rho        0 -cMass 0 -doRayleigh 0
element truss     76     75    89            1 1212   -rho        0 -cMass 0 -doRayleigh 0
element truss     77     75   137            1 1220   -rho        0 -cMass 0 -doRayleigh 0
element truss     78    128   109            1 1220   -rho        0 -cMass 0 -doRayleigh 0
element truss     79     75   129            1 1221   -rho        0 -cMass 0 -doRayleigh 0
element truss     80    110   109            1 1222   -rho        0 -cMass 0 -doRayleigh 0
element truss     81     75    99            1 1223   -rho        0 -cMass 0 -doRayleigh 0
element truss     82     63   109            1 1224   -rho        0 -cMass 0 -doRayleigh 0

# --------------------------------------------------------------------------------------------------------------
#
# M O D E L  D O M A I N  2  (6DOF)
#
# --------------------------------------------------------------------------------------------------------------

model BasicBuilder -ndm 3 -ndf 6

# --------------------------------------------------------------------------------------------------------------
# N O D E S
# --------------------------------------------------------------------------------------------------------------

# node $NodeTag $XCoord $Ycoord $Zcoord

node      1            0        12.33            0
node      2            0        12.33          3.4
node      3            0           14          3.4
node      4         4.03        12.33          3.4
node      5            0            7            0
node      6            0            7          3.4
node      7            0        12.33          6.4
node      8            0           14          6.4
node      9         7.35        12.33            0
node     10         4.03            7          3.4
node     11         4.03        12.33          6.4
node     12         7.35        12.33          3.4
node     13         7.35           14          3.4
node     14            0            7          6.4
node     15          6.2            7          3.4
node     16         7.35            7            0
node     17         4.03            7          6.4
node     18            0        12.33          9.4
node     19            0           14          9.4
node     20         7.35            7          3.4
node     21         7.35        12.33          6.4
node     22         7.35           14          6.4
node     23         4.03        12.33          9.4
node     24          6.2            7          6.4
node     25          8.5            7          3.4
node     26            0         1.68            0
node     27            0            7          9.4
node     28         7.35            7          6.4
node     29            0         1.68          3.4
node     30        10.68        12.33          3.4
node     31         4.03            7          9.4
node     32         4.03         1.68          3.4
node     33          8.5            7          6.4
node     34         7.35        12.33          9.4
node     35         7.35           14          9.4
node     36          6.2         1.68            0
node     37            0        12.33         12.4
node     38        10.68            7          3.4
node     39            0         1.68          6.4
node     40        10.68        12.33          6.4
node     41          6.2            7          9.4
node     42            0           14         12.4
node     43          6.2         1.68          3.4
node     44            0            0          3.4
node     45         4.03        12.33         12.4
node     46         4.03         1.68          6.4
node     47         7.35            7          9.4
node     48            0          8.1         12.4
node     49         7.35         1.68          3.4
node     50         4.03            0          3.4
node     51            0            7         12.4
node     52        10.68            7          6.4
node     53          8.5         1.68            0
node     54         4.03          8.1         12.4
node     55          8.5            7          9.4
node     56          6.2         1.68          6.4
node     57            0            0          6.4
node     58            0          5.9         12.4
node     59          8.5         1.68          3.4
node     60         4.03            7         12.4
node     61            0         1.68          9.4
node     62        10.68        12.33          9.4
node     63         7.35        12.33         12.4
node     64         7.35         1.68          6.4
node     65         4.03            0          6.4
node     66         7.35           14         12.4
node     67         4.03          5.9         12.4
node     68         14.7        12.33            0
node     69         7.35            0          3.4
node     70         4.03         1.68          9.4
node     71          8.5         1.68          6.4
node     72         14.7        12.33          3.4
node     73         14.7           14          3.4
node     74        10.68            7          9.4
node     75         7.35            7         12.4
node     76            0        12.33         15.4
node     77        10.68         1.68          3.4
node     78            0           14         15.4
node     79          6.2         1.68          9.4
node     80            0            0          9.4
node     81         14.7            7            0
node     82         7.35            0          6.4
node     83         4.03        12.33         15.4
node     84         7.35         1.68          9.4
node     85         14.7            7          3.4
node     86         4.03            0          9.4
node     87         14.7        12.33          6.4
node     88         14.7           14          6.4
node     89            0            7         15.4
node     90            0         1.68         12.4
node     91        10.68        12.33         12.4
node     92        10.68         1.68          6.4
node     93          8.5         1.68          9.4
node     94        10.68            0          3.4
node     95         4.03            7         15.4
node     96         4.03         1.68         12.4
node     97         14.7            7          6.4
node     98        10.68          8.1         12.4
node     99         7.35        12.33         15.4
node    100         7.35            0          9.4
node    101        10.68            7         12.4
node    102         14.7        12.33          9.4
node    103          6.2         1.68         12.4
node    104            0            0         12.4
node    105        10.68            0          6.4
node    106         14.7           14          9.4
node    107        10.68          5.9         12.4
node    108        10.68         1.68          9.4
node    109         7.35            7         15.4
node    110         7.35         1.68         12.4
node    111         14.7         1.68            0
node    112         14.7            7          9.4
node    113          8.5         1.68         12.4
node    114         14.7         1.68          3.4
node    115            0         1.68         15.4
node    116        10.68        12.33         15.4
node    117        10.68            0          9.4
node    118         7.35            0         12.4
node    119         4.03         1.68         15.4
node    120         14.7        12.33         12.4
node    121         14.7         1.68          6.4
node    122         14.7           14         12.4
node    123        10.68            7         15.4
node    124         14.7            0          3.4
node    125        10.68         1.68         12.4
node    126         14.7          8.1         12.4
node    127            0            0         15.4
node    128         14.7            7         12.4
node    129         7.35         1.68         15.4
node    130         14.7            0          6.4
node    131         14.7          5.9         12.4
node    132         14.7         1.68          9.4
node    133         14.7        12.33         15.4
node    134         14.7           14         15.4
node    135         14.7            0          9.4
node    136        10.68         1.68         15.4
node    137         14.7            7         15.4
node    138         14.7         1.68         12.4
node    139         14.7            0         12.4
node    140         14.7         1.68         15.4
node    141         14.7            0         15.4

# --------------------------------------------------------------------------------------------------------------
# F O R C E - B A S E D   B E A M - C O L U M N   E L E M E N T S
# --------------------------------------------------------------------------------------------------------------

# Geometric Transformation

geomTransf Linear 1 -1 0 0
geomTransf PDelta 3 -1 0 0
geomTransf Corotational 5 -1 0 0
geomTransf Linear 2  0 1 0
geomTransf PDelta 4  0 1 0
geomTransf Corotational 6 0 1 0

# Sections Definition used by forceBeamColumn Elements
# (ïnly if they have not already been defined on this model domain)

uniaxialMaterial Concrete04 218 -28000 -0.002 -0.2 3e+07 2900 0
uniaxialMaterial Concrete04 254 -28000 -0.002 -0.0002 3e+07 2900 0
uniaxialMaterial Steel02 256 222000 1.26e+08 -0.000286 15 0.925 0.15 0 1 0 1 0


section Fiber 284 -GJ 38660  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     41  -0.095000  -0.345000   0.095000   0.345000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     45   0.095000  -0.375000   0.125000   0.375000
patch rect 254      2     45  -0.125000  -0.375000  -0.095000   0.375000
patch rect 254     11      2  -0.095000   0.345000   0.095000   0.375000
patch rect 254     11      2  -0.095000  -0.375000   0.095000  -0.345000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00350000   0.095000   0.345000   0.095000  -0.345000
layer straight 256  2   0.00350000  -0.095000   0.345000  -0.095000  -0.345000
}


section Fiber 285 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00210000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00210000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 287 -GJ 46790  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     49  -0.095000  -0.405000   0.095000   0.405000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     53   0.095000  -0.435000   0.125000   0.435000
patch rect 254      2     53  -0.125000  -0.435000  -0.095000   0.435000
patch rect 254     11      2  -0.095000   0.405000   0.095000   0.435000
patch rect 254     11      2  -0.095000  -0.435000   0.095000  -0.405000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00430000   0.095000   0.405000   0.095000  -0.405000
layer straight 256  2   0.00430000  -0.095000   0.405000  -0.095000  -0.405000
}


section Fiber 288 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00380000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00380000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 290 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00320000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00320000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 292 -GJ 38660  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     41  -0.095000  -0.345000   0.095000   0.345000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     45   0.095000  -0.375000   0.125000   0.375000
patch rect 254      2     45  -0.125000  -0.375000  -0.095000   0.375000
patch rect 254     11      2  -0.095000   0.345000   0.095000   0.375000
patch rect 254     11      2  -0.095000  -0.375000   0.095000  -0.345000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00270000   0.095000   0.345000   0.095000  -0.345000
layer straight 256  2   0.00270000  -0.095000   0.345000  -0.095000  -0.345000
}


section Fiber 293 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00140000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00140000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 295 -GJ 29901  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     34  -0.095000  -0.280000   0.095000   0.280000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     38   0.095000  -0.310000   0.125000   0.310000
patch rect 254      2     38  -0.125000  -0.310000  -0.095000   0.310000
patch rect 254     11      2  -0.095000   0.280000   0.095000   0.310000
patch rect 254     11      2  -0.095000  -0.310000   0.095000  -0.280000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00320000   0.095000   0.280000   0.095000  -0.280000
layer straight 256  2   0.00320000  -0.095000   0.280000  -0.095000  -0.280000
}


section Fiber 296 -GJ 20835  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     15  -0.120000  -0.155000   0.120000   0.155000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     19   0.120000  -0.185000   0.150000   0.185000
patch rect 254      2     19  -0.150000  -0.185000  -0.120000   0.185000
patch rect 254     11      2  -0.120000   0.155000   0.120000   0.185000
patch rect 254     11      2  -0.120000  -0.185000   0.120000  -0.155000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00230000   0.120000   0.155000   0.120000  -0.155000
layer straight 256  2   0.00230000  -0.120000   0.155000  -0.120000  -0.155000
}


section Fiber 298 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00250000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00250000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 2100 -GJ 15545  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     20  -0.095000  -0.170000   0.095000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     24   0.095000  -0.200000   0.125000   0.200000
patch rect 254      2     24  -0.125000  -0.200000  -0.095000   0.200000
patch rect 254     11      2  -0.095000   0.170000   0.095000   0.200000
patch rect 254     11      2  -0.095000  -0.200000   0.095000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00250000   0.095000   0.170000   0.095000  -0.170000
layer straight 256  2   0.00250000  -0.095000   0.170000  -0.095000  -0.170000
}


section Fiber 2101 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00130000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00130000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 2103 -GJ 15545  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     20  -0.095000  -0.170000   0.095000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     24   0.095000  -0.200000   0.125000   0.200000
patch rect 254      2     24  -0.125000  -0.200000  -0.095000   0.200000
patch rect 254     11      2  -0.095000   0.170000   0.095000   0.200000
patch rect 254     11      2  -0.095000  -0.200000   0.095000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00250000   0.095000   0.170000   0.095000  -0.170000
layer straight 256  2   0.00250000  -0.095000   0.170000  -0.095000  -0.170000
}


section Fiber 2104 -GJ 9576  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     14  -0.095000  -0.120000   0.095000   0.120000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     18   0.095000  -0.150000   0.125000   0.150000
patch rect 254      2     18  -0.125000  -0.150000  -0.095000   0.150000
patch rect 254     11      2  -0.095000   0.120000   0.095000   0.150000
patch rect 254     11      2  -0.095000  -0.150000   0.095000  -0.120000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00200000   0.095000   0.120000   0.095000  -0.120000
layer straight 256  2   0.00200000  -0.095000   0.120000  -0.095000  -0.120000
}


section Fiber 2106 -GJ 5745  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.085000  -0.095000   0.085000   0.095000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     17   0.085000  -0.125000   0.115000   0.125000
patch rect 254      2     17  -0.115000  -0.125000  -0.085000   0.125000
patch rect 254     11      3  -0.085000   0.095000   0.085000   0.125000
patch rect 254     11      3  -0.085000  -0.125000   0.085000  -0.095000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00090000   0.085000   0.095000   0.085000  -0.095000
layer straight 256  2   0.00090000  -0.085000   0.095000  -0.085000  -0.095000
}


section Fiber 2107 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00130000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00130000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 2109 -GJ 12707  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     21  -0.085000  -0.170000   0.085000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     27   0.085000  -0.200000   0.115000   0.200000
patch rect 254      2     27  -0.115000  -0.200000  -0.085000   0.200000
patch rect 254     11      3  -0.085000   0.170000   0.085000   0.200000
patch rect 254     11      3  -0.085000  -0.200000   0.085000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00110000   0.085000   0.170000   0.085000  -0.170000
layer straight 256  2   0.00110000  -0.085000   0.170000  -0.085000  -0.170000
}


section Fiber 2110 -GJ 45070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.170000  -0.170000   0.170000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.170000  -0.200000   0.200000   0.200000
patch rect 254      2     15  -0.200000  -0.200000  -0.170000   0.200000
patch rect 254     11      2  -0.170000   0.170000   0.170000   0.200000
patch rect 254     11      2  -0.170000  -0.200000   0.170000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00050000   0.170000   0.170000   0.170000  -0.170000
layer straight 256  2   0.00050000  -0.170000   0.170000  -0.170000  -0.170000
}


section Fiber 2112 -GJ 15545  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     20  -0.095000  -0.170000   0.095000   0.170000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     24   0.095000  -0.200000   0.125000   0.200000
patch rect 254      2     24  -0.125000  -0.200000  -0.095000   0.200000
patch rect 254     11      2  -0.095000   0.170000   0.095000   0.200000
patch rect 254     11      2  -0.095000  -0.200000   0.095000  -0.170000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00070000   0.095000   0.170000   0.095000  -0.170000
layer straight 256  2   0.00070000  -0.095000   0.170000  -0.095000  -0.170000
}


section Fiber 2113 -GJ 5745  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.085000  -0.095000   0.085000   0.095000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     17   0.085000  -0.125000   0.115000   0.125000
patch rect 254      2     17  -0.115000  -0.125000  -0.085000   0.125000
patch rect 254     11      3  -0.085000   0.095000   0.085000   0.125000
patch rect 254     11      3  -0.085000  -0.125000   0.085000  -0.095000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00050000   0.085000   0.095000   0.085000  -0.095000
layer straight 256  2   0.00050000  -0.085000   0.095000  -0.085000  -0.095000
}


section Fiber 2115 -GJ 5745  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218     11     11  -0.085000  -0.095000   0.085000   0.095000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     17   0.085000  -0.125000   0.115000   0.125000
patch rect 254      2     17  -0.115000  -0.125000  -0.085000   0.125000
patch rect 254     11      3  -0.085000   0.095000   0.085000   0.125000
patch rect 254     11      3  -0.085000  -0.125000   0.085000  -0.095000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00090000   0.085000   0.095000   0.085000  -0.095000
layer straight 256  2   0.00090000  -0.085000   0.095000  -0.085000  -0.095000
}


section Fiber 2116 -GJ 18415  {

# Create the core fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 218  15  12  0.0 0.0 0.0    0.145  0 360

# Create the cover fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 254  15   3  0.0 0.0    0.145         0.175 0 360

# Create the reinforcing bars

# layer circ $matTag $numFiber $areaFiber $yCenter $zCenter $radius <$startAng $endAng>
layer circ 256  16   0.00100000  0.0 0.0    0.145
}


section Fiber 2118 -GJ 18415  {

# Create the core fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 218  15  12  0.0 0.0 0.0    0.145  0 360

# Create the cover fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 254  15   3  0.0 0.0    0.145         0.175 0 360

# Create the reinforcing bars

# layer circ $matTag $numFiber $areaFiber $yCenter $zCenter $radius <$startAng $endAng>
layer circ 256  16   0.00360000  0.0 0.0    0.145
}


section Fiber 2119 -GJ 18415  {

# Create the core fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 218  15  12  0.0 0.0 0.0    0.145  0 360

# Create the cover fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 254  15   3  0.0 0.0    0.145         0.175 0 360

# Create the reinforcing bars

# layer circ $matTag $numFiber $areaFiber $yCenter $zCenter $radius <$startAng $endAng>
layer circ 256  16   0.00290000  0.0 0.0    0.145
}


section Fiber 2121 -GJ 18415  {

# Create the core fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 218  15  12  0.0 0.0 0.0    0.145  0 360

# Create the cover fibers

# patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad $startAng $endAng
patch circ 254  15   3  0.0 0.0    0.145         0.175 0 360

# Create the reinforcing bars

# layer circ $matTag $numFiber $areaFiber $yCenter $zCenter $radius <$startAng $endAng>
layer circ 256  16   0.00100000  0.0 0.0    0.145
}


section Fiber 234 -GJ 14205  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     11  -0.085000  -0.185000   0.085000   0.185000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.085000  -0.215000   0.115000   0.215000
patch rect 254      2     15  -0.115000  -0.215000  -0.085000   0.215000
patch rect 254      4      2  -0.085000   0.185000   0.085000   0.215000
patch rect 254      4      2  -0.085000  -0.215000   0.085000  -0.185000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00320000  -0.085000   0.185000   0.085000   0.185000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00210000  -0.085000  -0.185000   0.085000  -0.185000
}


section Fiber 259 -GJ 9999  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     14  -0.070000  -0.185000   0.070000   0.185000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     18   0.070000  -0.215000   0.100000   0.215000
patch rect 254      2     18  -0.100000  -0.215000  -0.070000   0.215000
patch rect 254      4      2  -0.070000   0.185000   0.070000   0.215000
patch rect 254      4      2  -0.070000  -0.215000   0.070000  -0.185000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00540000  -0.070000   0.185000   0.070000   0.185000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00610000  -0.070000  -0.185000   0.070000  -0.185000
}


section Fiber 260 -GJ 14205  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     11  -0.085000  -0.185000   0.085000   0.185000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     15   0.085000  -0.215000   0.115000   0.215000
patch rect 254      2     15  -0.115000  -0.215000  -0.085000   0.215000
patch rect 254      4      2  -0.085000   0.185000   0.085000   0.215000
patch rect 254      4      2  -0.085000  -0.215000   0.085000  -0.185000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00320000  -0.085000   0.185000   0.085000   0.185000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00350000  -0.085000  -0.185000   0.085000  -0.185000
}


section Fiber 261 -GJ 55935  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      6      7  -0.170000  -0.195000   0.170000   0.195000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1      9   0.170000  -0.225000   0.200000   0.225000
patch rect 254      1      9  -0.200000  -0.225000  -0.170000   0.225000
patch rect 254      6      1  -0.170000   0.195000   0.170000   0.225000
patch rect 254      6      1  -0.170000  -0.225000   0.170000  -0.195000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00840000  -0.170000   0.195000   0.170000   0.195000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00810000  -0.170000  -0.195000   0.170000  -0.195000
}


section Fiber 262 -GJ 31914  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      6     19  -0.095000  -0.295000   0.095000   0.295000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1     21   0.095000  -0.325000   0.125000   0.325000
patch rect 254      1     21  -0.125000  -0.325000  -0.095000   0.325000
patch rect 254      6      1  -0.095000   0.295000   0.095000   0.325000
patch rect 254      6      1  -0.095000  -0.325000   0.095000  -0.295000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00670000  -0.095000   0.295000   0.095000   0.295000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00710000  -0.095000  -0.295000   0.095000  -0.295000
}


section Fiber 263 -GJ 2070  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     16  -0.035000  -0.125000   0.035000   0.125000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     20   0.035000  -0.155000   0.065000   0.155000
patch rect 254      2     20  -0.065000  -0.155000  -0.035000   0.155000
patch rect 254      4      2  -0.035000   0.125000   0.035000   0.155000
patch rect 254      4      2  -0.035000  -0.155000   0.035000  -0.125000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00110000  -0.035000   0.125000   0.035000   0.125000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00160000  -0.035000  -0.125000   0.035000  -0.125000
}


section Fiber 264 -GJ 17771  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     14  -0.085000  -0.220000   0.085000   0.220000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     18   0.085000  -0.250000   0.115000   0.250000
patch rect 254      2     18  -0.115000  -0.250000  -0.085000   0.250000
patch rect 254      4      2  -0.085000   0.220000   0.085000   0.250000
patch rect 254      4      2  -0.085000  -0.250000   0.085000  -0.220000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00300000  -0.085000   0.220000   0.085000   0.220000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00510000  -0.085000  -0.220000   0.085000  -0.220000
}


section Fiber 265 -GJ 22968  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     17  -0.085000  -0.270000   0.085000   0.270000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     21   0.085000  -0.300000   0.115000   0.300000
patch rect 254      2     21  -0.115000  -0.300000  -0.085000   0.300000
patch rect 254      4      2  -0.085000   0.270000   0.085000   0.300000
patch rect 254      4      2  -0.085000  -0.300000   0.085000  -0.270000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00370000  -0.085000   0.270000   0.085000   0.270000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00510000  -0.085000  -0.270000   0.085000  -0.270000
}


section Fiber 266 -GJ 13072  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     17  -0.070000  -0.230000   0.070000   0.230000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     21   0.070000  -0.260000   0.100000   0.260000
patch rect 254      2     21  -0.100000  -0.260000  -0.070000   0.260000
patch rect 254      4      2  -0.070000   0.230000   0.070000   0.260000
patch rect 254      4      2  -0.070000  -0.260000   0.070000  -0.230000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00370000  -0.070000   0.230000   0.070000   0.230000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00510000  -0.070000  -0.230000   0.070000  -0.230000
}


section Fiber 267 -GJ 55935  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      6      7  -0.170000  -0.195000   0.170000   0.195000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1      9   0.170000  -0.225000   0.200000   0.225000
patch rect 254      1      9  -0.200000  -0.225000  -0.170000   0.225000
patch rect 254      6      1  -0.170000   0.195000   0.170000   0.225000
patch rect 254      6      1  -0.170000  -0.225000   0.170000  -0.195000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.01190000  -0.170000   0.195000   0.170000   0.195000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.01630000  -0.170000  -0.195000   0.170000  -0.195000
}


section Fiber 268 -GJ 33933  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      6     20  -0.095000  -0.310000   0.095000   0.310000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1     22   0.095000  -0.340000   0.125000   0.340000
patch rect 254      1     22  -0.125000  -0.340000  -0.095000   0.340000
patch rect 254      6      1  -0.095000   0.310000   0.095000   0.340000
patch rect 254      6      1  -0.095000  -0.340000   0.095000  -0.310000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00620000  -0.095000   0.310000   0.095000   0.310000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.01140000  -0.095000  -0.310000   0.095000  -0.310000
}


section Fiber 270 -GJ 55935  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      6      7  -0.170000  -0.195000   0.170000   0.195000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1      9   0.170000  -0.225000   0.200000   0.225000
patch rect 254      1      9  -0.200000  -0.225000  -0.170000   0.225000
patch rect 254      6      1  -0.170000   0.195000   0.170000   0.225000
patch rect 254      6      1  -0.170000  -0.225000   0.170000  -0.195000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.01000000  -0.170000   0.195000   0.170000   0.195000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.01090000  -0.170000  -0.195000   0.170000  -0.195000
}


section Fiber 271 -GJ 15835  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      4     20  -0.070000  -0.270000   0.070000   0.270000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      2     24   0.070000  -0.300000   0.100000   0.300000
patch rect 254      2     24  -0.100000  -0.300000  -0.070000   0.300000
patch rect 254      4      2  -0.070000   0.270000   0.070000   0.300000
patch rect 254      4      2  -0.070000  -0.300000   0.070000  -0.270000


# Create the Top bars (face on local z positive dir)

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256   2    0.00370000  -0.070000   0.270000   0.070000   0.270000

# Create the Bottom bars (face on local z negative dir)

layer straight 256   2   0.00510000  -0.070000  -0.270000   0.070000  -0.270000
}


section Fiber 280 -GJ 156018  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      0     11  -1.220000  -0.095000   1.220000   0.095000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1     15   1.220000  -0.125000   1.250000   0.125000
patch rect 254      1     15  -1.250000  -0.125000  -1.220000   0.125000
patch rect 254      0      2  -1.220000   0.095000   1.220000   0.125000
patch rect 254      0      2  -1.220000  -0.125000   1.220000  -0.095000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.01080000   1.220000   0.095000   1.220000  -0.095000
layer straight 256  2   0.01080000  -1.220000   0.095000  -1.220000  -0.095000
}


section Fiber 281 -GJ 156018  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      0     11  -1.220000  -0.095000   1.220000   0.095000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1     15   1.220000  -0.125000   1.250000   0.125000
patch rect 254      1     15  -1.250000  -0.125000  -1.220000   0.125000
patch rect 254      0      2  -1.220000   0.095000   1.220000   0.125000
patch rect 254      0      2  -1.220000  -0.125000   1.220000  -0.095000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00800000   1.220000   0.095000   1.220000  -0.095000
layer straight 256  2   0.00800000  -1.220000   0.095000  -1.220000  -0.095000
}


section Fiber 282 -GJ 156018  {

# Create the Core fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 218      0     11  -1.220000  -0.095000   1.220000   0.095000

# Create the Cover fibers

# patch rect $matTag $numSubdivY $numSubdivZ $yI $zI $yJ $zJ
patch rect 254      1     15   1.220000  -0.125000   1.250000   0.125000
patch rect 254      1     15  -1.250000  -0.125000  -1.220000   0.125000
patch rect 254      0      2  -1.220000   0.095000   1.220000   0.125000
patch rect 254      0      2  -1.220000  -0.125000   1.220000  -0.095000

# Create the corner bars

# layer straight $matTag $numFiber $areaFiber $yStart $zStart $yEnd $zEnd
layer straight 256  2   0.00390000   1.220000   0.095000   1.220000  -0.095000
layer straight 256  2   0.00390000  -1.220000   0.095000  -1.220000  -0.095000
}

# Force-Based Beam Column Element Definition

# element forceBeamColumn $eleTag $iNode $jNode $numIntgrPts $secTag $transfTag

element forceBeamColumn     83     15     20  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     84     20     25  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     85     24     28  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     86     28     33  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     87     41     47  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     88     47     55  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     89     26     29  3   2121  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     90     36     43  3    284  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     91     53     59  3    284  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     92    111    114  3   2121  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     93      5      6  3   2119  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     94     81     85  3   2119  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     95      1      2  3   2116  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     96      9     12  3   2118  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     97     68     72  3   2116  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     98     29     39  3    290  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn     99     43     56  3    292  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    100     59     71  3    292  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    101    114    121  3    290  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    102      6     14  3    288  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    103     85     97  3    288  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    104      2      7  3    285  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    105     12     21  3    287  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    106     72     87  3    285  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    107     39     61  3    298  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    108     56     79  3   2100  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    109     71     93  3   2100  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    110    121    132  3    298  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    111     14     27  3    296  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    112     97    112  3    296  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    113      7     18  3    293  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    114     21     34  3    295  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    115     87    102  3    293  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    116     61     90  3   2107  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    117     79    103  3   2109  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    118     93    113  3   2109  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    119    132    138  3   2107  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    120     27     51  3   2104  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    121     47     75  3   2106  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    122    112    128  3   2104  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    123     18     37  3   2101  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    124     34     63  3   2103  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    125    102    120  3   2101  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    126     90    115  3   2110  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    127    110    129  3   2112  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    128    138    140  3   2110  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    129     51     89  3   2113  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    130     75    109  3   2115  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    131    128    137  3   2113  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    132     37     76  3   2110  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    133     63     99  3   2112  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    134    120    133  3   2110  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    135     29     32  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    136     32     43  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    137     43     49  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    138     49     59  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    139     59     77  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    140     77    114  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    141      6     10  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    142     10     15  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    143     25     38  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    144     38     85  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    145      2      4  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    146      4     12  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    147     12     30  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    148     30     72  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    149     39     46  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    150     46     56  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    151     56     64  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    152     64     71  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    153     71     92  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    154     92    121  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    155     14     17  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    156     17     24  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    157     33     52  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    158     52     97  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    159      7     11  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    160     11     21  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    161     21     40  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    162     40     87  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    163     61     70  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    164     70     79  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    165     79     84  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    166     84     93  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    167     93    108  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    168    108    132  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    169     27     31  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    170     31     41  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    171     55     74  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    172     74    112  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    173     18     23  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    174     23     34  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    175     34     62  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    176     62    102  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    177     90     96  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    178     96    103  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    179    103    110  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    180    110    113  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    181    113    125  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    182    125    138  3    270  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    183     58     67  3    263  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    184    107    131  3    263  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    185     51     60  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    186     60     75  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    187     75    101  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    188    101    128  3    268  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    189     48     54  3    263  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    190     98    126  3    263  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    191     37     45  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    192     45     63  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    193     63     91  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    194     91    120  3    267  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    195    115    119  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    196    119    129  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    197    129    136  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    198    136    140  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    199     89     95  3    262  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    200     95    109  3    262  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    201    109    123  3    262  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    202    123    137  3    262  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    203     76     83  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    204     83     99  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    205     99    116  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    206    116    133  3    261  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    207     44     29  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    208     29      6  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    209      6      2  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    210      2      3  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    211     50     32  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    212     32     10  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    213     10      4  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    214     43     15  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    215     69     49  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    216     20     12  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    217     12     13  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    218     59     25  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    219     94     77  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    220     77     38  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    221     38     30  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    222    124    114  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    223    114     85  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    224     85     72  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    225     72     73  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    226     57     39  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    227     39     14  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    228     14      7  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    229      7      8  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    230     65     46  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    231     46     17  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    232     17     11  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    233     56     24  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    234     82     64  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    235     28     21  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    236     21     22  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    237     71     33  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    238    105     92  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    239     92     52  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    240     52     40  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    241    130    121  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    242    121     97  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    243     97     87  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    244     87     88  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    245     80     61  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    246     61     27  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    247     27     18  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    248     18     19  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    249     86     70  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    250     70     31  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    251     31     23  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    252     79     41  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    253    100     84  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    254     47     34  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    255     34     35  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    256     93     55  3    271  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    257    117    108  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    258    108     74  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    259     74     62  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    260    135    132  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    261    132    112  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    262    112    102  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    263    102    106  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    264    104     90  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    265     90     58  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    266     58     51  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    267     51     48  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    268     48     37  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    269     37     42  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    270     96     67  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    271     67     60  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    272     60     54  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    273     54     45  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    274    118    110  3    265  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    275    110     75  3    265  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    276     75     63  3    265  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    277     63     66  3    265  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    278    125    107  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    279    107    101  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    280    101     98  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    281     98     91  3    266  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    282    139    138  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    283    138    131  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    284    131    128  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    285    128    126  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    286    126    120  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    287    120    122  3    264  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    288    127    115  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    289    115     89  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    290     89     76  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    291     76     78  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    292    119     95  3    259  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    293     95     83  3    259  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    294    129    109  3    260  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    295    109     99  3    260  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    296    136    123  3    259  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    297    123    116  3    259  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    298    141    140  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    299    140    137  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    300    137    133  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    301    133    134  3    234  1   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    302     16     20  3    280  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    303     20     28  3    281  2   -iter   10   1.00e-06   -mass        0
element forceBeamColumn    304     28     47  3    282  2   -iter   10   1.00e-06   -mass        0

# --------------------------------------------------------------------------------------------------------------
#
# D O M A I N  C O M M O N S
#
# --------------------------------------------------------------------------------------------------------------

# --------------------------------------------------------------------------------------------------------------
# R E C O R D E R S
# --------------------------------------------------------------------------------------------------------------

recorder Node -file Node_displacements.out -time -nodeRange 1 211 -dof 1 2 3 disp
recorder Node -file Node_rotations.out -time -nodeRange 1 211 -dof 4 5 6 disp
recorder Node -file Node_forceReactions.out -time -nodeRange 1 211 -dof 1 2 3 reaction
recorder Node -file Node_momentReactions.out -time -nodeRange 1 211 -dof 4 5 6 reaction
recorder Element -file ForceBeamColumn_localForce.out -time -ele 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 localForce
recorder Element -file ForceBeamColumn_basicDeformation.out -time -ele 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 basicDeformation
recorder Element -file ForceBeamColumn_plasticDeformation.out -time -ele 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 plasticDeformation
recorder Element -file Truss_axialForce.out -time -ele 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 axialForce
recorder Element -file Truss_deformations.out -time -ele 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 deformations

logFile "Model 1366 - Infilled.log"

puts ""
puts " __   __       __          __                   _       "
puts "/ _ .|  \\ _|_ /  \\ _  _ _ (_  _ _ _  | _ |_ _ _(_ _  _ _"
puts "\\__)||__/  |  \\__/|_)(-| )__)(-(-_)  || )|_(-| | (_|(_(-"
puts "                  |                                     "
puts "                                                  v2.6.0"
puts "Analysis summary"
puts ""
puts "Interval 1 : Static - [expr int(1+10)] steps"
puts ""
puts "----------------"
puts ""
set time_start [clock seconds]
puts "Starting analysis at [clock format $time_start -format %H:%M:%S]\n"

# --------------------------------------------------------------------------------------------------------------
#
# I N T E R V A L   1
#
# --------------------------------------------------------------------------------------------------------------

puts "Running interval 1\n"

# Loads - Plain Pattern

pattern Plain 100 Linear {
  load      2        0        0  -132.82
  load      3        0        0   -12.25
  load      6        0        0  -103.06
  load      7        0        0  -134.42
  load      8        0        0   -12.25
  load     12        0        0  -159.95
  load     13        0        0   -21.75        0        0        0
  load     14        0        0  -104.65
  load     18        0        0  -134.42
  load     19        0        0   -12.25
  load     20        0        0  -283.12
  load     21        0        0  -162.98
  load     22        0        0   -21.75        0        0        0
  load     27        0        0  -103.43
  load     28        0        0  -283.12
  load     29        0        0   -79.63
  load     34        0        0  -161.42
  load     35        0        0   -21.75        0        0        0
  load     37        0        0  -134.42
  load     39        0        0   -81.23
  load     42        0        0   -12.25
  load     43        0        0   -99.81
  load     44        0        0   -30.97
  load     47        0        0  -283.12
  load     51        0        0  -122.81
  load     56        0        0   -99.81
  load     57        0        0   -30.97
  load     59        0        0   -99.81
  load     61        0        0   -81.23
  load     63        0        0  -160.04
  load     66        0        0   -21.75        0        0        0
  load     69        0        0   -24.88        0        0        0
  load     71        0        0   -99.81
  load     72        0        0  -132.82
  load     73        0        0   -12.25
  load     75        0        0  -241.49
  load     76        0        0  -108.12
  load     78        0        0     -8.8        0        0        0
  load     79        0        0   -97.63
  load     80        0        0   -30.97
  load     82        0        0   -24.88        0        0        0
  load     85        0        0  -103.06
  load     87        0        0  -134.42
  load     88        0        0   -12.25
  load     89        0        0   -72.94
  load     90        0        0   -81.23
  load     93        0        0   -97.63
  load     97        0        0  -104.65
  load     99        0        0   -108.7
  load    100        0        0   -24.88        0        0        0
  load    102        0        0  -134.42
  load    103        0        0   -92.25        0        0        0
  load    104        0        0   -30.97
  load    106        0        0   -12.25
  load    109        0        0  -153.32
  load    112        0        0  -103.43
  load    113        0        0   -92.25        0        0        0
  load    114        0        0   -79.63
  load    115        0        0   -50.12
  load    118        0        0   -24.88        0        0        0
  load    120        0        0  -134.42
  load    121        0        0   -81.23
  load    122        0        0   -12.25
  load    124        0        0   -30.97
  load    127        0        0    -18.6        0        0        0
  load    128        0        0  -122.81
  load    129        0        0  -132.18
  load    130        0        0   -30.97
  load    132        0        0   -81.23
  load    133        0        0  -108.12
  load    134        0        0     -8.8        0        0        0
  load    135        0        0   -30.97
  load    137        0        0   -72.94
  load    138        0        0   -81.23
  load    139        0        0   -30.97
  load    140        0        0   -50.12
  load    141        0        0    -18.6        0        0        0
}

# recording the initial status

record

# Perform eigenvalue analysis

puts "Running eigenvalue analysis\n"

set numModes 6

# Record eigenvectors

for { set k 1 } { $k <= $numModes } { incr k } {
    recorder Node -file [format "Mode_%i.out" $k] -nodeRange 1 211 -dof 1 2 3 "eigen $k"
}

set lambda [eigen -fullGenLapack $numModes]

# Calculate periods

set T {}
foreach lam $lambda {
    lappend T [expr 6.283185/sqrt($lam)]
}

# Write periods file

set period "Periods.out"
set Periods [open $period "w"]
foreach t $T {
    puts $Periods "$t"
}
close $Periods

# Analysis options

system BandGeneral
numberer RCM
constraints Transformation
integrator LoadControl 0.1
test NormDispIncr 1e-08 50 2
algorithm Newton
analysis Static

set Lincr 0.100000
set Nsteps 10
set committedSteps 1
set LoadCounter 0

variable strIni {}
variable testTypeStatic NormDispIncr
variable TolStatic 1e-08
variable maxNumIterStatic 50
variable algorithmTypeStatic Newton

for {set i 1} { $i <= $Nsteps } {incr i 1} {
    set t [format "%7.5f" [expr [getTime] + $Lincr]]
    puts -nonewline "(1) $algorithmTypeStatic$strIni LF $t "
    set AnalOk [analyze 1]
    if {$AnalOk !=0} {
        break
    } else {
        set LoadCounter [expr $LoadCounter+1.0]
        set committedSteps [expr $committedSteps+1]
    }
}

if {$AnalOk != 0} {; # if analysis fails, alternative algorithms and substepping is applied
    set firstFail 1
    set AnalOk 0
    set Nk 1
    set returnToInitStepFlag 0
    while {$LoadCounter < $Nsteps && $AnalOk == 0} {
        if {($Nk==2 && $AnalOk==0) || ($Nk==1 && $AnalOk==0)} {
            set Nk 1
            if {$returnToInitStepFlag} {
                puts "\nBack to initial step\n"
                set returnToInitStepFlag 0
            }
            if {$firstFail == 0} { # for the first time only, do not repeat previous failed step
                integrator LoadControl $Lincr; # reset to original increment
                set t [format "%7.5f" [expr [getTime] + $Lincr]]
                puts -nonewline "(1) $algorithmTypeStatic$strIni LF $t "
                set AnalOk [analyze 1]; # zero for convergence
            } else {
                set AnalOk 1
                set firstFail 0
            }
            if {$AnalOk != 0} {
                puts "\nTrying NR/initial\n"
                test NormDispIncr $TolStatic $maxNumIterStatic 2
                algorithm Newton -initial
                set t [format "%7.5f" [expr [getTime] + $Lincr]]
                puts -nonewline "(1) Newton/Ini LF $t "
                set AnalOk [analyze 1]
                test $testTypeStatic $TolStatic $maxNumIterStatic 2
                algorithm $algorithmTypeStatic
            }
            if {$AnalOk == 0} {
                set LoadCounter [expr $LoadCounter+1.0/$Nk]
                set committedSteps [expr $committedSteps+1]
            }
        }; # end if Nk=1
        # substepping /2
        if {($AnalOk !=0 && $Nk==1) || ($AnalOk==0 && $Nk==4)} {
            set Nk 2; # reduce step size
            set continueFlag 1
            puts "\nInitial step is divided by 2\n"
            set LincrReduced [expr $Lincr/$Nk]
            integrator LoadControl $LincrReduced
            for {set ik 1} {$ik <=$Nk} {incr ik 1} {
                if {$continueFlag==0} {
                    break
                }
                set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                puts -nonewline "(1) $algorithmTypeStatic$strIni LF $t "
                set AnalOk [analyze 1]; # zero for convergence
                if {$AnalOk != 0} {
                    puts "\nTrying NR/initial\n"
                    test NormDispIncr $TolStatic $maxNumIterStatic 2
                    algorithm Newton -initial
                    set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                    puts -nonewline "(1) Newton/Ini LF $t "
                    set AnalOk [analyze 1]
                    test $testTypeStatic $TolStatic $maxNumIterStatic 2
                    algorithm $algorithmTypeStatic
                }
                if {$AnalOk == 0} {
                    set LoadCounter [expr $LoadCounter+1.0/$Nk]
                    set committedSteps [expr $committedSteps+1]
                } else {
                    set continueFlag 0
                }
            }
            if {$AnalOk == 0} {
                set returnToInitStepFlag 1
            }
        }; # end if Nk=2
        # substepping /4
        if {($AnalOk !=0 && $Nk==2) || ($AnalOk==0 && $Nk==8)} {
            set Nk 4; # reduce step size
            set continueFlag 1
            puts "\nInitial step is divided by 4\n"
            set LincrReduced [expr $Lincr/$Nk]
            integrator LoadControl $LincrReduced
            for {set ik 1} {$ik <=$Nk} {incr ik 1} {
                if {$continueFlag==0} {
                    break
                }
                set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                puts -nonewline "(1) $algorithmTypeStatic$strIni LF $t "
                set AnalOk [analyze 1]; # zero for convergence
                if {$AnalOk != 0} {
                    puts "\nTrying NR/initial\n"
                    test NormDispIncr $TolStatic $maxNumIterStatic 2
                    algorithm Newton -initial
                    set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                    puts -nonewline "(1) Newton/Ini LF $t "
                    set AnalOk [analyze 1]
                    test $testTypeStatic $TolStatic $maxNumIterStatic 2
                    algorithm $algorithmTypeStatic
                }
                if {$AnalOk == 0} {
                    set LoadCounter [expr $LoadCounter+1.0/$Nk]
                    set committedSteps [expr $committedSteps+1]
                } else {
                    set continueFlag 0
                }
            }
            if {$AnalOk == 0} {
                set returnToInitStepFlag 1
            }
        }; # end if Nk=4
        # substepping /8
        if {$AnalOk !=0 && $Nk==4 || ($Nk == 16 && $AnalOk == 0)} {
            set Nk 8; # reduce step size
            set continueFlag 1
            puts "\nInitial step is divided by 8\n"
            set LincrReduced [expr $Lincr/$Nk]
            integrator LoadControl $LincrReduced
            for {set ik 1} {$ik <=$Nk} {incr ik 1} {
                if {$continueFlag==0} {
                    break
                }
                set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                puts -nonewline "(1) $algorithmTypeStatic$strIni LF $t "
                set AnalOk [analyze 1]; # zero for convergence
                if {$AnalOk != 0} {
                    puts "\nTrying NR/initial\n"
                    test NormDispIncr $TolStatic $maxNumIterStatic 2
                    algorithm Newton -initial
                    set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                    puts -nonewline "(1) Newton/Ini LF $t "
                    set AnalOk [analyze 1]
                    test $testTypeStatic $TolStatic $maxNumIterStatic 2
                    algorithm $algorithmTypeStatic
                }
                if {$AnalOk == 0} {
                    set LoadCounter [expr $LoadCounter+1.0/$Nk]
                    set committedSteps [expr $committedSteps+1]
                } else {
                    set continueFlag 0
                }
            }
            if {$AnalOk == 0} {
                set returnToInitStepFlag 1
            }
        }; # end if Nk=8
        # substepping /16
        if {($Nk == 8 && $AnalOk!=0)} {
            set Nk 16; # reduce step size
            set continueFlag 1
            puts "\nInitial step is divided by 16\n"
            set LincrReduced [expr $Lincr/$Nk]
            integrator LoadControl $LincrReduced
            for {set ik 1} {$ik <=$Nk} {incr ik 1} {
                if {$continueFlag==0} {
                    break
                }
                set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                puts -nonewline "(1) $algorithmTypeStatic$strIni LF $t "
                set AnalOk [analyze 1]; # zero for convergence
                if {$AnalOk != 0} {
                    puts "\nTrying NR/initial\n"
                    test NormDispIncr $TolStatic $maxNumIterStatic 2
                    algorithm Newton -initial
                    set t [format "%7.5f" [expr [getTime] + $LincrReduced]]
                    puts -nonewline "(1) Newton/Ini LF $t "
                    set AnalOk [analyze 1]
                    test $testTypeStatic $TolStatic $maxNumIterStatic 2
                    algorithm $algorithmTypeStatic
                }
                if {$AnalOk == 0} {
                    set LoadCounter [expr $LoadCounter+1.0/$Nk]
                    set committedSteps [expr $committedSteps+1]
                } else {
                    set continueFlag 0
                }
            }
            if {$AnalOk == 0} {
                set returnToInitStepFlag 1
            }
        }; # end if Nk=16
    }; # end while loop
}; # end if AnalOk

if {$AnalOk == 0} {
    puts "\nAnalysis completed SUCCESSFULLY"
    puts "Committed steps : $committedSteps\n"
} else {
    puts "\nAnalysis FAILED"
    puts "Committed steps : $committedSteps\n"
}

# all previously defined patterns are constant for so on.

loadConst -time 0.0

# --------------------------------------------------------------------------------------------------------------

set hour 0.0
set minute 0.0
set second 0.0
set time_end [clock seconds]
set analysisTime [expr $time_end-$time_start]

puts "Analysis finished at [clock format $time_end -format %H:%M:%S]\n"

if {$analysisTime<60} {
    if {$analysisTime==0} {
        puts "Analysis time : less than one second"
    } elseif {$analysisTime==1} {
        puts "Analysis time : 1 second"
    } else {
        puts "Analysis time : $analysisTime seconds"
    }

}  elseif {$analysisTime<3600} {
    set minutes [expr $analysisTime/60]
    set seconds [expr $analysisTime%60]

    if {$minutes==1} {
        puts -nonewline "Analysis time : 1 minute"
    } else {
        puts -nonewline "Analysis time : $minutes minutes"
    }

    if {$seconds==0} {
        puts ""
    } elseif {$seconds==1} {
        puts " and 1 second"
    } else {
        puts " and $seconds seconds"
    }

} else  {
    set hours [expr $analysisTime/3600]
    set minutes [expr ($analysisTime%3600)/60]
    set seconds [expr ($analysisTime%3600)%60]

    if {$hours==1} {
        puts -nonewline "Analysis time : 1 hour"
    } else {
        puts -nonewline "Analysis time : $hours hours"
    }

    if {$minutes==0} {
    } elseif {$minute==1} {
        puts -nonewline ", 1 minute"
    } else {
        puts -nonewline ", $minutes minutes"
    }

    if {$seconds==0} {
        puts ""
    } elseif {$second==1} {
        puts " and 1 second"
    } else {
        puts " and $seconds seconds"
    }
}

# --------------------------------------------------------------------------------------------------------------
#
# M E T A D A T A
#
# --------------------------------------------------------------------------------------------------------------

# Number of nodes
# 211

# Elements 1D
# 304

# Elements 2D
# 0

# Elements 3D
# 0

# ForceBeamColumn
# 222
# 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 

# Truss
# 82
# 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 

# ----------------------------------------------------------------------------------------------------------------------------------------------------------
#
# F R A M E   L O C A L   A X E S   O R I E N T A T I O N
#
# ----------------------------------------------------------------------------------------------------------------------------------------------------------
#
#      ID                           Type                          Local-x                          Local-y                          Local-z          Literal
#
#      83                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#      84                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#      85                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#      86                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#      87                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#      88                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#      89                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      90                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      91                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      92                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      93                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      94                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      95                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      96                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      97                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      98                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#      99                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     100                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     101                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     102                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     103                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     104                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     105                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     106                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     107                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     108                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     109                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     110                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     111                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     112                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     113                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     114                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     115                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     116                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     117                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     118                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     119                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     120                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     121                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     122                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     123                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     124                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     125                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     126                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     127                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     128                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     129                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     130                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     131                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     132                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     133                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     134                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     135                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     136                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     137                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     138                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     139                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     140                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     141                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     142                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     143                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     144                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     145                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     146                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     147                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     148                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     149                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     150                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     151                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     152                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     153                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     154                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     155                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     156                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     157                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     158                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     159                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     160                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     161                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     162                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     163                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     164                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     165                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     166                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     167                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     168                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     169                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     170                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     171                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     172                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     173                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     174                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     175                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     176                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     177                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     178                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     179                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     180                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     181                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     182                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     183                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     184                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     185                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     186                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     187                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     188                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     189                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     190                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     191                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     192                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     193                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     194                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     195                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     196                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     197                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     198                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     199                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     200                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     201                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     202                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     203                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     204                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     205                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     206                forceBeamColumn     {+1.00000 +0.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-0.00000 +1.00000 +0.00000}     { +X -Z +Y }
#     207                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     208                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     209                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     210                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     211                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     212                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     213                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     214                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     215                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     216                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     217                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     218                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     219                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     220                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     221                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     222                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     223                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     224                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     225                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     226                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     227                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     228                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     229                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     230                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     231                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     232                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     233                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     234                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     235                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     236                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     237                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     238                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     239                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     240                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     241                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     242                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     243                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     244                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     245                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     246                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     247                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     248                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     249                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     250                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     251                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     252                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     253                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     254                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     255                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     256                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     257                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     258                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     259                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     260                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     261                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     262                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     263                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     264                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     265                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     266                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     267                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     268                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     269                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     270                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     271                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     272                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     273                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     274                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     275                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     276                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     277                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     278                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     279                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     280                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     281                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     282                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     283                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     284                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     285                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     286                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     287                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     288                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     289                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     290                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     291                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     292                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     293                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     294                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     295                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     296                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     297                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     298                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     299                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     300                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     301                forceBeamColumn     {+0.00000 +1.00000 +0.00000}     {+0.00000 +0.00000 -1.00000}     {-1.00000 +0.00000 +0.00000}     { +Y -Z -X }
#     302                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     303                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
#     304                forceBeamColumn     {+0.00000 +0.00000 +1.00000}     {+1.00000 +0.00000 +0.00000}     {+0.00000 +1.00000 +0.00000}     { +Z +X +Y }
